@@ -21,10 +21,10 @@
 
 #include <config.h>
 #include "htmlengine.h"
-#include "htmlengine-edit-paste.h"
 #include "htmlimage.h"
 #include "htmlcluealigned.h"
 
+#include "htmlengine-edit-cut-and-paste.h"
 #include "htmlengine-edit-images.h"
 
 
@@ -42,14 +42,15 @@ html_engine_insert_image (HTMLEngine *e,
 			  HTMLHAlignType halign,
 			  HTMLVAlignType valign,
 			  gint8 hspace,
-			  gint8 vspace)
+			  gint8 vspace,
+			  gboolean reload)
 {
 	HTMLObject *image;
 
 	g_return_if_fail (e != NULL);
 	g_return_if_fail (HTML_IS_ENGINE (e));
 
-	image = html_image_new (e->image_factory,
+	image = html_image_new (html_engine_get_image_factory (e),
 				file,
 				url,
 				target,
@@ -57,10 +58,9 @@ html_engine_insert_image (HTMLEngine *e,
 				percent_width, percent_height,
 				border,
 				border_color,
-				valign);
+				valign, reload);
 
 	html_image_set_spacing (HTML_IMAGE (image), hspace, vspace);
 
-	html_engine_paste_object (e, image, TRUE);
-	html_object_destroy (image);
+	html_engine_paste_object (e, image, 1);
 }
